
*=====================================================================================*
*                                  preparation.do                                     *
*=====================================================================================*

*-------------------------------------------------------------------------------------*
*  van den Berg, Kalmijn, Leopold, 2020. replication files                          		  *
*  last update: April 2020	                                                       *
*  data: OKiN												                          *
*-------------------------------------------------------------------------------------*


set more off

use "${data}\OKIN_ANCHOR_1.1_UvA_2017.dta", clear
merge 1:1 persid using "${data}\samenwoonhuwelijk.dta"

*-----------------------------------------------------------------------------*
*  Prepare variables                                                          *
*-----------------------------------------------------------------------------*

* Gender 
recode r1sex (1 = 1) (else = 0), gen(male) 			

* Age
fre r1age

* Leaving early/late and with or without partner
// never leaving is 999 on r1lefth --> late home leaving 
recode r1lefth (-4/14 = .) 


gen leftp		= 1 if 	r1lefth>18  	& 	male==0								|			///
						r1lefth>19  	& 	male==1
replace leftp 	= 2 if 	r1lefth<=18 	& 	agestrtcohab1>=23 & male==0			|			///
						r1lefth<=18 	& 	agestrtcohab1==. & male==0			|			///
						r1lefth<=19 	& 	agestrtcohab1>=25 & male==1			|			///
						r1lefth<=19 	& 	agestrtcohab1==. & male==1	
replace leftp	= 3 if 	r1lefth<=18 	& 	agestrtcohab1<23 & agestrtcohab1!=. & male==0	|	////
						r1lefth<=19 	& 	agestrtcohab1<25 & agestrtcohab1!=. & male==1

recode leftp 	(1 = 1 "Late home leaving")									///
				(2 = 2 "Early home leaving, late union")						///
				(3 = 3 "Early home leaving, early union"), gen(left3)

* resident parent
/* We coded the parent the child lived with for the most years as the main parent. 
If the child lived same period with mother and father, we used the mother 
1 is with mother, 2 is with father, 3 is intact family */ 
gen par 	= 1 if xdbiofath<=xdbiomoth & xdbiomoth!=. | xdbiofath==.
replace par = 2 if xdbiofath>xdbiomoth & xdbiofath!=. | xdbiomoth==.
replace par = 3 if xfamtype==1

* Family structure 1 (intact, non-intact divorce, non-intact widowed) 
gen famstruc 		= 1 if xfamtype==1							// Intact
replace famstruc 	= 2 if xfamtype!=1 & xfamtype!=3			// Divorced parents
replace famstruc 	= 3 if xfamtype==3 							// Widowed

/* We coded stepconf as 1 if the partner of the resident parent is 3 or 4.
We coded stepclos as 1 if the relation to the partner of the resident partner is not 
close (4 5)
99 consists of people who have a stepparent but did not report on conflict or closeness */ 
* Step conflict 
gen stepconf 		= d3conf 	if 	par==1 & d3cores==2
replace stepconf 	= c3conf 	if 	par==2 & c3cores==2
replace stepconf 	= 99 		if 	par==1 & xdnewpmy!=. & d3conf==. & xdnewpmy!=0  | 	///
									par==2 & xdnewpfy!=. & c3conf==. & xdnewpfy!=0  
recode stepconf (3 4 = 1 "conflict") (1 2 = 0), gen(conflict)

* Step closeness 
gen stepclos 		= d3close 	if 	par==1 & d3cores==2
replace stepclos 	= c3close  	if 	par==2 & c3cores==2
replace stepclos 	= 99 		if 	par==1 & xdnewpmy!=. & d3close ==. & xdnewpmy!=0  | 	///
									par==2 & xdnewpfy!=. & c3close==. & xdnewpfy!=0  
recode stepclos (4 5 = 1 "not close") (else = 0), gen(notclose)
									
* Close and conflict combination
/* More detailed measure of closeness and conflict with stepparents for in the 
additional analyses. */
gen stepclosconf = 1 if conflict==0 & stepclos<4		// close and no conflict
replace stepclosconf = 2 if conflict==1 & stepclos<4  	// close and conflict
replace stepclosconf = 3 if conflict==0 & stepclos>3  	// not close and no conflict
replace stepclosconf = 4 if conflict==1 & stepclos>3  	// not close and conflict

recode stepclosconf (. =1 "single parent") (1 = 2 "close and no conflict step") ///
					(2 = 3 "close and conflict step") (3 = 4 "not close and no conflict step") ///
					(4 = 5 "not close and conflict step"), gen(stepcloscon)

* Having a stepparent
/* Binary measure coded as 1 if one has a stepparent and 0 if single parent). */ 
recode stepcloscon (1= 0) (else=1), gen(step)

* Financial situation parents
/* We use the financial situation of the parent the child lived with the longest. 
If this parent remarried, we used the financial situation of the parent and their 
partner */ 
recode ab4finan b3finan a3finan bd3finan ac3finan (-2 -1 = .)
gen finana 		= ab4finan
replace	finana	= b3finan  if par==1
replace	finana	= a3finan  if par==2
replace	finana	= bd3finan  if par==1 & bd3finan!=. & d3cores==2
replace	finana	= ac3finan  if  par==2 & ac3finan!=. & c3cores==2
recode finana (1 2 = 1) (3 = 2) (4 5 =3), gen(finan)

/* Recode closeness so that a higher value means closer */
* Conflict resident parent
gen confres = b3conf 	if par==1 
replace confres = a3conf if par==2

* Closeness resident parent
gen closeres = b3close 	if par==1 
replace closeres = a3close if par==2
recode closeres (5 = 1) (4 = 2) (3 = 3) (2 = 4) (1 = 5) 

* Conflict nonresident parent
gen confnonres = b3conf 	if par==2 
replace confnonres = a3conf if par==1 

* Closeness nonresident parent
gen closenonres = b3close 	if par==2
replace closenonres = a3close if par==1 

/* We base the number of siblings on all siblings that the respondent lived with 
in the same household and is from the resident parent. More than 6 siblings are 
coded as 6*/ 
* Number of siblings
recode ab1sib e1siblt ae1siblt bf1siblt f1siblt (. = 0)
gen sib = ab1sib + e1siblt + ae1siblt if par==2
replace sib = ab1sib + bf1siblt +  f1siblt if par==1
recode sib (6 7 8 9 10 11 12 14 = 6) 

* conflict between bioparents
recode ab3row (1 2 = 1 "Little") (3 4 = 2 "regular") (-2 . = 3 "DK"), gen(confpp)

* Gender stepparent
gen sexstep = d3sex if par==1
replace sexstep = c3sex if par==2
recode sexstep (2=1) (1=0), gen(femalestep)

* Age at separation parents
replace  r3asep = 0 if xlivsit>8 & xlivsit<12

* Age at introduction stepparent 
gen agestep = d3start if par==1 & d3cores==2
replace agestep = c3start if par==2 & c3cores==2

*-----------------------------------------------------------------------------*
*  Sample selection                                                           *
*-----------------------------------------------------------------------------*
// drop individuals with a stepparent with missing information about conflict with stepparent
drop if stepconf==99 | stepclos==99

// Keep only divorced families
keep if famstruc==2

// Drop people with no data from the cbs about living together
drop if _merge!=3 

// Drop if missing information about relevant variable 
drop if finana==.| par==. | closeres==. | confres==. | r1lefth==. 

*-----------------------------------------------------------------------------*
*  Center variables		                                                      *
*-----------------------------------------------------------------------------*
//center changenum
center  closeres confres sib r1birthy closenonres confnonres r3asep 

** Save
save  "${posted}\data.dta", replace
